# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
from typing import Any, TYPE_CHECKING

from azure.core.rest import HttpRequest, HttpResponse
from azure.mgmt.core import ARMPipelineClient

from . import models as _models
from ._configuration import SignalRManagementClientConfiguration
from ._serialization import Deserializer, Serializer
from .operations import (
    Operations,
    SignalRCustomCertificatesOperations,
    SignalRCustomDomainsOperations,
    SignalROperations,
    SignalRPrivateEndpointConnectionsOperations,
    SignalRPrivateLinkResourcesOperations,
    SignalRReplicasOperations,
    SignalRSharedPrivateLinkResourcesOperations,
    UsagesOperations,
)

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from azure.core.credentials import TokenCredential


class SignalRManagementClient:  # pylint: disable=client-accepts-api-version-keyword,too-many-instance-attributes
    """REST API for Azure SignalR Service.

    :ivar operations: Operations operations
    :vartype operations: azure.mgmt.signalr.operations.Operations
    :ivar signal_r: SignalROperations operations
    :vartype signal_r: azure.mgmt.signalr.operations.SignalROperations
    :ivar usages: UsagesOperations operations
    :vartype usages: azure.mgmt.signalr.operations.UsagesOperations
    :ivar signal_rcustom_certificates: SignalRCustomCertificatesOperations operations
    :vartype signal_rcustom_certificates:
     azure.mgmt.signalr.operations.SignalRCustomCertificatesOperations
    :ivar signal_rcustom_domains: SignalRCustomDomainsOperations operations
    :vartype signal_rcustom_domains: azure.mgmt.signalr.operations.SignalRCustomDomainsOperations
    :ivar signal_rprivate_endpoint_connections: SignalRPrivateEndpointConnectionsOperations
     operations
    :vartype signal_rprivate_endpoint_connections:
     azure.mgmt.signalr.operations.SignalRPrivateEndpointConnectionsOperations
    :ivar signal_rprivate_link_resources: SignalRPrivateLinkResourcesOperations operations
    :vartype signal_rprivate_link_resources:
     azure.mgmt.signalr.operations.SignalRPrivateLinkResourcesOperations
    :ivar signal_rreplicas: SignalRReplicasOperations operations
    :vartype signal_rreplicas: azure.mgmt.signalr.operations.SignalRReplicasOperations
    :ivar signal_rshared_private_link_resources: SignalRSharedPrivateLinkResourcesOperations
     operations
    :vartype signal_rshared_private_link_resources:
     azure.mgmt.signalr.operations.SignalRSharedPrivateLinkResourcesOperations
    :param credential: Credential needed for the client to connect to Azure. Required.
    :type credential: ~azure.core.credentials.TokenCredential
    :param subscription_id: The ID of the target subscription. The value must be an UUID. Required.
    :type subscription_id: str
    :param base_url: Service URL. Default value is "https://management.azure.com".
    :type base_url: str
    :keyword api_version: Api Version. Default value is "2023-08-01-preview". Note that overriding
     this default value may result in unsupported behavior.
    :paramtype api_version: str
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
     Retry-After header is present.
    """

    def __init__(
        self,
        credential: "TokenCredential",
        subscription_id: str,
        base_url: str = "https://management.azure.com",
        **kwargs: Any
    ) -> None:
        self._config = SignalRManagementClientConfiguration(
            credential=credential, subscription_id=subscription_id, **kwargs
        )
        self._client: ARMPipelineClient = ARMPipelineClient(base_url=base_url, config=self._config, **kwargs)

        client_models = {k: v for k, v in _models.__dict__.items() if isinstance(v, type)}
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)
        self._serialize.client_side_validation = False
        self.operations = Operations(self._client, self._config, self._serialize, self._deserialize)
        self.signal_r = SignalROperations(self._client, self._config, self._serialize, self._deserialize)
        self.usages = UsagesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.signal_rcustom_certificates = SignalRCustomCertificatesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.signal_rcustom_domains = SignalRCustomDomainsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.signal_rprivate_endpoint_connections = SignalRPrivateEndpointConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.signal_rprivate_link_resources = SignalRPrivateLinkResourcesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.signal_rreplicas = SignalRReplicasOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.signal_rshared_private_link_resources = SignalRSharedPrivateLinkResourcesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )

    def _send_request(self, request: HttpRequest, **kwargs: Any) -> HttpResponse:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = client._send_request(request)
        <HttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.HttpResponse
        """

        request_copy = deepcopy(request)
        request_copy.url = self._client.format_url(request_copy.url)
        return self._client.send_request(request_copy, **kwargs)

    def close(self) -> None:
        self._client.close()

    def __enter__(self) -> "SignalRManagementClient":
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details: Any) -> None:
        self._client.__exit__(*exc_details)
